sudo_user

Function sudo_user 

pub fn sudo_user() -> Option<SudoUser>
Returns info about the real user behind sudo, if applicable.

Looks up SUDO_USER in the environment. Returns None if the variable is unset, empty, or set to “root” (running sudo as root is a no-op).